Skip to contents

Get the names of all tables in the connected VegVault database. This function can be called at any stage of the pipeline.

Usage

explore_vault(con = NULL)

Arguments

con

A vault_pipe object created by open_vault().

Value

A character vector of table names present in the VegVault database.