Skip to contents

For each Sample, get information about Taxa and their abundances from the Vault database.

Usage

get_taxa(
  con = NULL,
  classify_to = c("original", "species", "genus", "family"),
  classification_data = NULL,
  verbose = TRUE
)

Arguments

con

A connection to the Vault database.

classify_to

A character vector specifying the taxonomic level to classify the taxa to. The options are original, species, genus, and family.

classification_data

An optional data.frame (or tibble) used instead of the TaxonClassification table in the database. Must contain taxon_id and the column matching classify_to (e.g. taxon_genus when classify_to = "genus"). If NULL (default), the database table is used. Obtain a valid table via get_classification_table(con, return_raw_data = TRUE).

verbose

A logical value indicating whether to print messages. Default is TRUE.

Value

A vault_pipe object with the data and the connection to the Vault database.