Skip to contents

Retrieve a tibble of distinct taxon names from the current vault_pipe query plan without executing a full extract_data() call. Requires get_taxa() to have been called earlier in the pipe so that taxon_id is present in the data.

Usage

get_taxon_names(con = NULL)

Arguments

con

A vault_pipe object. Must have been passed through get_taxa() so that a taxon_id column is present in con$data.

Value

A tibble with a single column taxon_name containing the distinct, alphabetically sorted taxon names available in the current query plan.