Get the names of all tables in the connected VegVault database. This function can be called at any stage of the pipeline.
Arguments
- con
A
vault_pipeobject created byopen_vault().
Get the names of all tables in the connected VegVault database. This function can be called at any stage of the pipeline.
A vault_pipe object created by open_vault().