For each Sample, get age uncertainty estimates from the Vault database.
Age uncertainties represent multiple iterations of age-depth modelling
and are stored in the SampleUncertainty table.
Arguments
- con
A
vault_pipeobject created byopen_vault(). Must already containsample_idin the data, i.e.get_samples()must have been called earlier in the pipe.- return_raw_data
A
logicalindicating whether to return raw long-format data. IfFALSE(default), returns a widetibblewith one row per sample identified bysample_nameand one column per iteration (e.g.iteration_1,iteration_2, ...). IfTRUE, returns the raw long-formattibblewith columnssample_id,iteration, andage_uncertainty.
Value
When return_raw_data = FALSE (default): a wide tibble with
sample_name as the key column and one column per age-model
iteration (e.g. iteration_1, iteration_2, ...), restricted to
the samples present in the incoming pipe.
When return_raw_data = TRUE: a long tibble with columns
sample_id, iteration, and age_uncertainty.