For each Sample, get information about Taxa and their abundances from the Vault database.
Usage
get_taxa(
con = NULL,
classify_to = c("original", "species", "genus", "family"),
classification_data = NULL,
verbose = TRUE
)Arguments
- con
A connection to the Vault database.
- classify_to
A character vector specifying the taxonomic level to classify the taxa to. The options are
original,species,genus, andfamily.- classification_data
An optional
data.frame(ortibble) used instead of theTaxonClassificationtable in the database. Must containtaxon_idand the column matchingclassify_to(e.g.taxon_genuswhenclassify_to = "genus"). IfNULL(default), the database table is used. Obtain a valid table viaget_classification_table(con, return_raw_data = TRUE).- verbose
A logical value indicating whether to print messages. Default is
TRUE.