Retrieve a tibble of distinct taxon names from the current vault_pipe
query plan without executing a full extract_data() call. Requires
get_taxa() to have been called earlier in the pipe so that taxon_id
is present in the data.
Arguments
- con
A
vault_pipeobject. Must have been passed throughget_taxa()so that ataxon_idcolumn is present incon$data.
Value
A tibble with a single column taxon_name containing the distinct,
alphabetically sorted taxon names available in the current query plan.