Pack the data into nested tibbles for easier access and manipulation. Only specific columns are selected and packed into the following nested tibbles:
data_samplesfor sample metadatadata_communityfor community (vegetation) datadata_traitsfor trait datadata_abioticfor abiotic data When thesel_datadoes not contain the required columns, the function will skip the respective data type.